==> MySQL-Admin-1.13.tar.gz: MySQL-Admin-1.13/cgi-bin/config/settings.pl <==
$VAR1 = {
          'database' => {
                          'name' => 'lze',
                          'CurrentUser' => 'lze',
                          'host' => 'localhost',
                          'user' => 'lze',
                          'password' => '',
                          'CurrentPass' => '',
                          'CurrentDb' => 'lze',
                          'CurrentHost' => 'localhost'
                        },
          'language' => 'en',
          'floodtime' => 10,
          'apacheconfig' => '/etc/apache2/sites-enabled/',
          'cgi' => {
                     'bin' => '/var/www/cgi-bin',
                     'serverName' => 'http://localhost',
                     'cookiePath' => '/',
                     'expires' => '+1y',
                     'style' => 'mysql',
                     'DocumentRoot' => '/var/www/html/',
                     'title' => 'MySQL::Admin'
                   },
          'actions' => '/var/www/cgi-bin/config/actions.pl',
          'size' => '16',
          'version' => '1.13',
          'admin' => {
                       'password' => 'testpass'
                     },
          'news' => {
                      'captcha' => 3,
                      'messages' => '5',
                      'right' => 5
                    },
          'config' => '/var/www/cgi-bin/config/settings.pl',
          'defaultAction' => 'ShowDatabases',
          'session' => '/var/www/cgi-bin/config/session.pl',
          'htmlright' => '2',
          'mod' => 'n',
          'translate' => '/var/www/cgi-bin/config/translate.pl',
          'saveTranslate' => '0',
          'files' => {
                       'owner' => 'lze',
                       'group' => 'lze',
                       'chmod' => '0755'
                     },
          'tree' => {
                      'links' => '/var/www/cgi-bin/config/links.pl',
                      'navigation' => '/var/www/cgi-bin/config/tree.pl'
                    },
          'uploads' => {
                         'chmod' => 438,
                         'maxlength' => '2100000000000000',
                         'path' => '/var/www/html//download',
                         'right' => 2,
                         'enabled' => 1
                       }
        };
$m_hrSettings =$VAR1;

==> MySQL-Admin-1.14.tar.gz: MySQL-Admin-1.14/cgi-bin/config/settings.pl <==
$VAR1 = {
          'htmlright' => '2',
          'translate' => '/var/www/cgi-bin/config/translate.pl',
          'config' => '/var/www/cgi-bin/config/settings.pl',
          'tree' => {
                      'navigation' => '/var/www/cgi-bin/config/tree.pl',
                      'links' => '/var/www/cgi-bin/config/links.pl'
                    },
          'database' => {
                          'CurrentDb' => 'lze',
                          'user' => 'lze',
                          'host' => 'localhost',
                          'CurrentUser' => 'lze',
                          'CurrentPass' => '',
                          'name' => 'lze',
                          'CurrentHost' => 'localhost',
                          'password' => ''
                        },
          'actions' => '/var/www/cgi-bin/config/actions.pl',
          'cgi' => {
                     'expires' => '+1y',
                     'style' => 'mysql',
                     'title' => 'MySQL::Admin',
                     'cookiePath' => '/',
                     'DocumentRoot' => '/var/www/html/',
                     'bin' => '/var/www/cgi-bin',
                     'serverName' => 'http://localhost'
                   },
          'version' => '1.14',
          'uploads' => {
                         'enabled' => 1,
                         'right' => 2,
                         'chmod' => 438,
                         'path' => '/var/www/html//download',
                         'maxlength' => '2100000000000000'
                       },
          'defaultAction' => 'ShowDatabases',
          'apacheconfig' => '/etc/apache2/sites-enabled/',
          'size' => '16',
          'floodtime' => 10,
          'news' => {
                      'messages' => '5',
                      'right' => 5,
                      'captcha' => 3
                    },
          'language' => 'en',
          'session' => '/var/www/cgi-bin/config/session.pl',
          'saveTranslate' => '0',
          'admin' => {
                       'password' => 'testpass'
                     },
          'files' => {
                       'group' => 'lze',
                       'chmod' => '0755',
                       'owner' => 'lze'
                     },
          'mod' => 'n'
        };
$m_hrSettings =$VAR1;
